local ldb = LibStub:GetLibrary("LibDataBroker-1.1");
local Toolkit = LibStub:GetLibrary("Toolkit-1.0");
local L = LibStub("AceLocale-3.0"):GetLocale("HealPoints") --Get the localization for our addon

local dataObject = ldb:NewDataObject("HealPoints", {
		type = "launcher",
		icon = "Interface\\Icons\\Spell_Holy_FlashHeal",
		label = "HealPoints",
		OnClick = function(clickedframe, button)
				if (button == "RightButton") then
					InterfaceOptionsFrame_OpenToCategory(HealPoints.options)					 
				else
					HealPoints:ToggleCalculator();
				end
			end
});

function dataObject:OnTooltipShow()
	self:AddLine(HIGHLIGHT_FONT_COLOR_CODE..L["HealPoints"]..FONT_COLOR_CODE_CLOSE); --|cffffcc00|r

	local currentStats = HealPointsCalculator:GetCurrentHealPoints();
	local iv, sv, spv, scrv, shrv, powerfulSpell, efficientSpell = HealPointsCalculator:ComputeHealPointsDelta(currentStats);

	local function spellToString(spell)
		if (spell == nil) then
			return "none";
		else	
			return HealPointsSpells:GetSpellLink(spell, false)
--			local spellName = GetSpellInfo(spell.id);
			--return spellName;
		end
	end

	self:AddDoubleLine(L["Heal Points"]..":", HIGHLIGHT_FONT_COLOR_CODE..Toolkit:IntToStrLocale(currentStats.healPoints)..FONT_COLOR_CODE_CLOSE);
	self:AddDoubleLine(L["Power Points"].." ("..spellToString(powerfulSpell)..")", HIGHLIGHT_FONT_COLOR_CODE..Toolkit:IntToStrLocale(currentStats.powerPoints)..FONT_COLOR_CODE_CLOSE);
	self:AddDoubleLine(L["Endurance Points"].." ("..spellToString(efficientSpell)..")", HIGHLIGHT_FONT_COLOR_CODE..Toolkit:IntToStrLocale(currentStats.endurancePoints)..FONT_COLOR_CODE_CLOSE);
	--self:AddLine(" ");
	--self:AddDoubleLine("Powerful Spell:", spellToString(powerfulSpell));
	--self:AddDoubleLine("Endurance Spell:", spellToString(efficientSpell));

	local minRel = math.min(iv, sv, spv, scrv, shrv);
	local maxRel = math.max(iv, sv, spv, scrv, shrv);

	assert(minRel);
	assert(maxRel);

	local function getStatText(hpFromStat)
		assert(hpFromStat);
		local s = Toolkit:RangeColorText(
				string.format("%.2f", hpFromStat),
				hpFromStat,
				minRel, HIGHLIGHT_FONT_COLOR.r, HIGHLIGHT_FONT_COLOR.g, HIGHLIGHT_FONT_COLOR.b, 
				maxRel, GREEN_FONT_COLOR.r, GREEN_FONT_COLOR.g, GREEN_FONT_COLOR.b)--]]
--		local s = HIGHLIGHT_FONT_COLOR_CODE..string.format("%.1f", hpFromStat)..FONT_COLOR_CODE_CLOSE;
		return s;
	end;

	self:AddLine(" ");
	self:AddDoubleLine(L["Relative Stat Values"], L["HealPoints"], 
			HIGHLIGHT_FONT_COLOR.r, HIGHLIGHT_FONT_COLOR.g, HIGHLIGHT_FONT_COLOR.b,
			HIGHLIGHT_FONT_COLOR.r, HIGHLIGHT_FONT_COLOR.g, HIGHLIGHT_FONT_COLOR.b);

	self:AddDoubleLine("1.00 "..SPELL_STAT4_NAME..":",     getStatText(iv)); --"Intellect"
	self:AddDoubleLine("1.00 "..SPELL_STAT5_NAME..":",     getStatText(sv)); --"Spirit"
	self:AddDoubleLine("1.00 "..STAT_SPELLPOWER..":",      getStatText(spv)); --"Spell Power"
	self:AddDoubleLine("1.00 "..COMBAT_RATING_NAME11..":", getStatText(scrv)); --"Crit Rating"
	self:AddDoubleLine("1.00 "..SPELL_HASTE..":",          getStatText(shrv)); --"Haste Rating"

	self:AddLine(" ");
	self:AddLine(GREEN_FONT_COLOR_CODE..L["Hint: Click to toggle the calculator window"]..FONT_COLOR_CODE_CLOSE);
	self:AddLine(GREEN_FONT_COLOR_CODE..L["Right-click to open the options menu"]..FONT_COLOR_CODE_CLOSE)
end;

local stats = { };

stats[1] = { stat = SPELL_STAT4_NAME,     statmod = 1 }; --"Intellect"
stats[2] = { stat = SPELL_STAT5_NAME,     statmod = 1 }; --"Spirit"
stats[3] = { stat = STAT_SPELLPOWER,      statmod = 1 }; --"Spell power"
stats[4] = { stat = COMBAT_RATING_NAME11, statmod = 1 }; --"Crit Rating"
stats[5] = { stat = SPELL_HASTE,          statmod = 1 }; --"Haste Rating"

function HealPoints:PrintMVS()
	local function statTableSort(e1, e2)
		if (e1.value > e2.value) then
			return true;
		else
			return false;
		end
	end

--	if HealPoints.ISHEALER then
		local currentStats = HealPointsCalculator:GetCurrentHealPoints();
		local iv, sv, spv, scrv, shrv, powerfulSpell, efficientSpell = HealPointsCalculator:ComputeHealPointsDelta(currentStats);

	--end

	stats[1].value = iv; --Intellect
	stats[2].value = sv; --Spirit
	stats[3].value = spv; --Spell Power
	stats[4].value = scrv; --Spell Crit Rating
	stats[5].value = shrv; --Spell Haste Rating
	table.sort(stats, statTableSort);
	

	self:Print("Most valuable stat ranking:");
	self:Print("--------------------------------------");
	for i = 1, table.getn(stats) do
		self:Print(string.format("1.00 %s: %.2f heal points", stats[i].stat, stats[i].value));
	end
end

